##  Prerequisites
  * Make sure you have a valid SAP LeanIX license.
  * Ensure your organization has access to SAP for Me with S-user credentials. Read more about S-users in [Access to SAP for Me](https://help.sap.com/docs/leanix/ea/access-to-sap-for-me?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to set up SAP for Me access for your organization.").
  * Your IT main contact has received the initial access information by email from SAP.
